@@ -42,11 +42,6 @@
   "Jira instance URL, like: https://acme.atlassian.net."
   :group 'jira :type 'string)
 
-(defcustom jira-secondary-urls nil
-  "List of secondary Jira instance URLs for multi-instance support.
-Each URL should be a complete Jira URL like: https://acme.atlassian.net"
-  :group 'jira :type '(repeat string))
-
 (defcustom jira-api-version 3
   "Jira API version (Versions 2 or 3 are allowed)."
   :group 'jira
@@ -75,7 +70,7 @@ Each URL should be a complete Jira URL like: https://acme.atlassian.net"
 
 (defvar jira-users
   nil
-  "Hash table of all Jira users, (displayName property) and ids (accountID).")
+  "Hash table of all Jira users, (displayName property) and ids (accountID)")
 
 (defvar jira-tempo-url "https://api.tempo.io/4/" "Jira Tempo API URL.")
 (defvar jira-account-id nil "Jira account ID of the current user.")
@@ -86,26 +81,21 @@ Each URL should be a complete Jira URL like: https://acme.atlassian.net"
 (defvar jira-filters nil "Jira user filters.")
 (defvar jira-projects nil "Jira projects (5 most recent).")
 (defvar jira-projects-versions nil "Jira project versions (releases).")
-(defvar jira-issue-types nil "Jira issue types available in the instance.")
-(defvar jira-search-endpoint nil "Cached search endpoint: \\='search\\=' or \\='search/jql\\='.")
+(defvar jira-search-endpoint nil "Cached search endpoint: 'search' or 'search/jql'.")
 
-(defvar jira-current-url nil "Currently active Jira URL for multi-instance support.")
-
-(defun jira-api--username ()
-  "Retrieve the username for current JIRA URL from config or auth-source."
+(defun jira-api--username (host)
+  "Retrieve the username for HOST from config or auth-source."
   (if (and jira-username (not (string= "" jira-username)))
       jira-username
-      (let* ((current-url (jira-api--get-current-url))
-             (auth-host (replace-regexp-in-string "https://" "" current-url))
+      (let* ((auth-host (replace-regexp-in-string "https://" "" host))
 	     (auth-info (car (auth-source-search :host auth-host :require '(:user)))))
 	(when auth-info (plist-get auth-info :user)))))
 
-(defun jira-api--token ()
-  "Retrieve the token for current JIRA URL from config or auth-source."
+(defun jira-api--token (host)
+  "Retrieve the token for HOST from config or auth-source."
   (if (and jira-token (not (string= "" jira-token)))
       jira-token
-      (let* ((current-url (jira-api--get-current-url))
-             (auth-host (replace-regexp-in-string "https://" "" current-url))
+      (let* ((auth-host (replace-regexp-in-string "https://" "" host))
 	     (auth-info (car (auth-source-search :host auth-host :require '(:secret)))))
 	(when auth-info (funcall (plist-get auth-info :secret))))))
 
@@ -126,47 +116,8 @@ Each URL should be a complete Jira URL like: https://acme.atlassian.net"
   "Generate the Authorization header for Jira Tempo API requests with TOKEN."
   (format "Bearer %s" token))
 
-(defun jira-api--available-urls ()
-  "Return list of available JIRA hosts for completion."
-  (if jira-secondary-urls
-      (cons jira-base-url jira-secondary-urls)
-    (list jira-base-url)))
-
-(defun jira-api--set-current-url (url)
-  "Set the currently active Jira host to URL and clear cached data."
-  (interactive (list (completing-read "JIRA host: " (jira-api--available-urls))))
-  (when (and url (not (string-empty-p url)))
-    (setq jira-current-url url)
-    (jira-api--clear-cache)
-    (message "Switched to JIRA host: %s" url)))
-
-(defun jira-api--get-current-url ()
-  "Get the currently active JIRA URL, falling back to base URL if not set."
-  (or jira-current-url jira-base-url))
-
-(defun jira-api--clear-cache ()
-  "Clear all cached JIRA data for URL switching."
-  (interactive)
-  (setq jira-users nil
-        jira-account-id nil
-        jira-fields nil
-        jira-active-issue-transitions nil
-        jira-statuses nil
-        jira-resolutions nil
-        jira-filters nil
-        jira-projects nil
-        jira-projects-versions nil
-        jira-search-endpoint nil
-        jira-issue-types nil))
-
-(defun jira-api--initialize-current-url ()
-  "Initialize URL system for backward compatibility.
-Ensure secondary URLs list exists for completion."
-  (unless jira-secondary-urls
-    (setq jira-secondary-urls '())))
-
 (defun jira-api--url (base-url endpoint)
-  "Generate the full API url from BASE-URL and the given ENDPOINT."
+  "Generate the full API url from BASE-URL and the given ENDPOINT"
   (let* ((version (if (numberp jira-api-version)
 		      (number-to-string jira-api-version)
 		    jira-api-version))
@@ -190,7 +141,7 @@ Ensure secondary URLs list exists for completion."
     (message "[Jira API Response Headers]: %s" (or response-headers "No headers"))
     (message "[Jira API Response Body]: %s" (or response-data "No response body"))))
 
-(cl-defun jira-api-call (verb endpoint &key params data callback parser sync error complete)
+(cl-defun jira-api-call (verb endpoint &key params data callback parser sync error)
   "Perform a VERB request to the Jira API ENDPOINT.
 
 PARAMS is a list of cons cells, DATA is the request body, and CALLBACK
@@ -201,43 +152,40 @@ Sync is a boolean indicating whether the request should be
 synchronous or not. If SYNC is non-nil, the request will block
 until it completes, otherwise it will be asynchronous.
 
-ERROR is a function to call if the request fails.
-COMPLETE is a function to call when the request completes (regardless of success/failure)."
-  (let ((current-url (jira-api--get-current-url)))
-    (message "[Jira API Call]: %s %s (URL: %s)" verb endpoint current-url)
-    (when (and jira-debug data)
-      (message "[Jira API Call Data]: %s" (json-encode data)))
-    (when (and jira-debug params)
-      (message "[Jira API Call Params]: %s" params))
-    (let* ((username (jira-api--username))
-	   (token (jira-api--token))
-	   (auth (jira-api--auth-header username token))
-	   (callback (cl-function
-		      (lambda (&key data response &allow-other-keys)
-			(when jira-debug
-			  (jira-api--callback-success-log data response))
-			(when callback
-			  (funcall callback data response))))))
-      (if (not auth) (message "[Jira API Error]: Authorization data not found"))
-      (if jira-debug (message "[Jira API Call]: Authorization %s: " auth))
-      (request
-	(jira-api--url current-url endpoint)
-	:type verb
-	:headers `(("Authorization" . ,auth) ("Content-Type" . "application/json"))
-	:sync sync
-	:params (or params '())
-	:data (if data (json-encode data) nil)
-	:parser (or parser 'json-read)
-	:success callback
-	:error (or error
-		   (cl-function
-		    (lambda (&key response error-thrown &allow-other-keys)
-		      (jira-api--callback-error-log response error-thrown))))
-	:complete complete))))
+ERROR is a function to call if the request fails."
+  (message "[Jira API Call]: %s %s" verb endpoint)
+  (when (and jira-debug data)
+    (message "[Jira API Call Data]: %s" (json-encode data)))
+  (when (and jira-debug params)
+    (message "[Jira API Call Params]: %s" params))
+  (let* ((username (jira-api--username jira-base-url))
+	 (token (jira-api--token jira-base-url))
+	 (auth (jira-api--auth-header username token))
+	 (callback (cl-function
+		    (lambda (&key data response &allow-other-keys)
+		      (when jira-debug
+			(jira-api--callback-success-log data response))
+		      (when callback
+			(funcall callback data response))))))
+    (if (not auth) (message "[Jira API Error]: Authorization data not found"))
+    (if jira-debug (message "[Jira API Call]: Authorization %s: " auth))
+    (request
+      (jira-api--url jira-base-url endpoint)
+      :type verb
+      :headers `(("Authorization" . ,auth) ("Content-Type" . "application/json"))
+      :sync sync
+      :params (or params '())
+      :data (if data (json-encode data) nil)
+      :parser (or parser 'json-read)
+      :success callback
+      :error (or error
+                 (cl-function
+                  (lambda (&key response error-thrown &allow-other-keys)
+                    (jira-api--callback-error-log response error-thrown)))))))
 
 (cl-defun jira-api-search (&key params callback sync errback)
   "Perform a JQL search, auto-detecting the correct endpoint.
-PARAMS are the search parameters. If we already know the endpoint, we use it directly."
+  ;; if we already know the endpoint, we use it directly"
   (if jira-search-endpoint
       (jira-api-call
        "GET" jira-search-endpoint :params params :callback callback :sync sync :error errback)
@@ -298,10 +246,10 @@ Calling CALLBACK if successful and passing PARAMS."
 FORCE will force the request even if the account ID is already stored.
 CALLBACK is the function to call after the request is done."
   (if (or force (not jira-account-id))
-      (let ((success (lambda (data _response)
-                       (setq jira-account-id (cdr (assoc 'accountId data)))))
-            (next (lambda (&rest _args) (when callback (funcall callback)))))
-        (jira-api-call "GET" "myself" :callback success :complete next))
+      (let ((c (lambda (data _response)
+                 (setq jira-account-id (cdr (assoc 'accountId data)))
+                 (when callback (funcall callback)))))
+        (jira-api-call "GET" "myself" :callback c))
     (when callback (funcall callback))))
 
 (cl-defun jira-api-get-fields (&key force callback)
@@ -310,18 +258,18 @@ CALLBACK is the function to call after the request is done."
 FORCE will force the request even if the fields are already stored.
 CALLBACK is the function to call after the request is done."
   (if (or force (not jira-fields))
-      (let ((success (lambda (data _response)
-                       (setq jira-fields
-			     (mapcar (lambda (field)
-                                       (cons (cdr (assoc 'name field))
-					     (cdr (assoc 'key field))))
-				     data))))
-            (next (lambda (&rest _args) (when callback (funcall callback)))))
-        (jira-api-call "GET" "field" :callback success :complete next))
+      (let ((c (lambda (data _response)
+                 (setq jira-fields
+                       (mapcar (lambda (field)
+                                 (cons (cdr (assoc 'name field))
+                                       (cdr (assoc 'key field))))
+                         data))
+                 (when callback (funcall callback)))))
+        (jira-api-call "GET" "field" :callback c))
     (when callback (funcall callback))))
 
 (defun jira-api-get-transitions (issue-keys)
-  "Get the transitions available for a list of ISSUE-KEYS."
+  "Get the transitions available for a a list of ISSUE-KEYS"
   ;; Jira API version 2 does not support bulk transitions
   (let* ((bulk (if (= jira-api-version 3) t nil))
 	 (format-transition
@@ -342,7 +290,7 @@ CALLBACK is the function to call after the request is done."
     (if bulk
 	(jira-api-call
 	 "GET" "bulk/issues/transition"
-	 :params `(("issueIdsOrKeys" . ,(mapconcat #'identity issue-keys ",")))
+	 :params `(("issueIdsOrKeys" . ,(mapconcat 'identity issue-keys ",")))
 	 :callback (lambda (data response)
                      (setq jira-active-issue-transitions
 			   (funcall extract data response))))
@@ -361,9 +309,9 @@ CALLBACK is the function to call after the request is done."
         (jira-api-call
          "GET" "status"
          :callback
-         (lambda (data _response) (setq jira-statuses (mapcar fmt data)))
-         :complete
-         (lambda (&rest _args) (when callback (funcall callback)))))
+         (lambda (data _response)
+           (setq jira-statuses (mapcar fmt data))
+           (when callback (funcall callback)))))
     (when callback (funcall callback))))
 
 (cl-defun jira-api-get-resolutions (&key force callback)
@@ -381,9 +329,8 @@ CALLBACK is the function to call after the request is done."
 	     ;; Jira UI represents with the "Unresolved" key the
 	     ;; resolutions for fields that don't have a resolution set.
 	     ;; If we find this value, we will send a nil
-             (setq jira-resolutions (cons (cons "Unresolved" nil) resolutions))))
-         :complete
-         (lambda (&rest _args) (when callback (funcall callback)))))
+             (setq jira-resolutions (cons (cons "Unresolved" nil) resolutions)))
+           (when callback (funcall callback)))))
     (when callback (funcall callback))))
 
 (cl-defun jira-api-get-filters (&key force callback)
@@ -392,42 +339,13 @@ CALLBACK is the function to call after the request is done."
 FORCE will force the request even if the filters are already stored.
 CALLBACK is the function to call after the request is done."
   (if (or force (not jira-filters))
-      (let* ((fmt (lambda (s) (cons (alist-get 'name s) (alist-get 'jql s))))
-             (success-cb (lambda (data _response) (setq jira-filters (mapcar fmt data))))
-             ;; Some Jira instances (especially older Server versions) don't support
-             ;; the `filter/my` endpoint, so we try `filter/favourite` as fallback
-             (error-cb
-              (cl-function
-               (lambda (&key response error-thrown &allow-other-keys)
-                 (if (and response (= (request-response-status-code response) 404))
-                     (jira-api-call "GET" "filter/favourite"
-                                    :callback success-cb
-                                    :complete (lambda (&rest _args) (when callback (funcall callback))))
-                   (jira-api--callback-error-log response error-thrown))))))
+      (let* ((fmt (lambda (s) (cons (alist-get 'name s) (alist-get 'jql s)))))
         (jira-api-call
          "GET" "filter/my?includeFavourites=true"
-         :callback success-cb
-         :error error-cb
-         :complete (lambda (&rest _args) (when callback (funcall callback)))))
-    (when callback (funcall callback))))
-
-(cl-defun jira-api-get-issue-types (&key force callback)
-  "Get the list of available issue types.
-
-FORCE will force the request even if the issue types are already stored.
-CALLBACK is the function to call after the request is done."
-  (if (or force (not jira-issue-types))
-      (let* ((fmt (lambda (s) (cons (alist-get 'name s) (alist-get 'id s)))))
-         (jira-api-call
-         "GET" "issuetype"
          :callback
-         (lambda (data _response) (setq jira-issue-types (mapcar fmt data)))
-         :error
-         (lambda (&rest args)
-           (message "Failed to fetch issue types: %S" args))
-         :complete
-         (lambda (&rest _args) (when callback (funcall callback)))))
-    (when callback (funcall callback))))
+         (lambda (data _response)
+           (setq jira-filters (mapcar fmt data))
+           (when callback (funcall callback)))))))
 
 (cl-defun jira-api-get-projects (&key force callback)
   "Get the 10 most recent projects.
@@ -442,9 +360,7 @@ CALLBACK is the function to call after the request is done."
          :callback
          (lambda (data _)
            (setq jira-projects (mapcar fmt data))
-           (jira-api-get-versions :force t :callback callback))
-         :complete
-         (lambda (&rest _args) (when callback (funcall callback)))))
+           (jira-api-get-versions :force t :callback callback))))
     (when callback (funcall callback))))
 
 (cl-defun jira-api-get-versions (&key force callback)
@@ -471,7 +387,8 @@ CALLBACK is the function to call after the request is done."
 (cl-defun jira-api-get-users (&key force)
   "Fetch the list of all Jira user names and IDs and store it in `jira-users'.
 
-If FORCE is non-nil, re-fetches the user list."
+If FORCE is non-nil, re-fetches the user list.
+"
   (interactive)
   (when (or (not jira-users)
             force)
@@ -485,7 +402,7 @@ If FORCE is non-nil, re-fetches the user list."
                        (maxResults . ,jira-users-max-results))
                      :callback
                      (lambda (data _response)
-                       (mapc (lambda (u)
+                       (mapc #'(lambda (u)
                                  (let ((id (alist-get 'accountId u))
                                        (name (alist-get 'displayName u)))
                                    (unless (eq :json-false (alist-get 'active u))
@@ -495,8 +412,8 @@ If FORCE is non-nil, re-fetches the user list."
 
 (cl-defun jira-api-get-create-metadata (project-key issue-type-id &key callback sync)
   "Get the metadata for creating an issue in PROJECT-KEY with ISSUE-TYPE-ID.
-CALLBACK is the function to call after the request is done.
-SYNC determines if the call should be synchronous."
+
+CALLBACK is the function to call after the request is done."
   (let* ((url (format "issue/createmeta/%s/issuetypes/%s"
 		      project-key issue-type-id))
          (response (jira-api-call "GET" url :params `(("maxResults" . 100)) :callback callback :sync sync)))
@@ -504,23 +421,12 @@ SYNC determines if the call should be synchronous."
       (request-response-data response))))
 
 (cl-defun jira-api-get-project-issue-types (project-key &key callback sync)
-  "Get the issue types available for PROJECT-KEY.
-Optionally calls CALLBACK if provided and makes the request synchronous if SYNC."
+  "Get the issue types available for PROJECT-KEY, optionally CALLBACK if provided
+and making the request synchronous if SYNC."
   (let* ((url (format "issue/createmeta/%s/issuetypes" project-key))
 	 (response (jira-api-call "GET" url :callback callback :sync sync)))
     (when sync (request-response-data response))))
 
-(cl-defun jira-api-get-linked-issues (issue-key &key callback sync)
-  "Get linked issues for ISSUE-KEY.
-
-CALLBACK is the function to call after the request is done.
-SYNC determines if the request should be synchronous."
-  (jira-api-call "GET"
-                 (format "issue/%s" issue-key)
-                 :params `(("fields" . "issuelinks"))
-                 :callback callback
-                 :sync sync))
-
 (cl-defun jira-api-get-basic-data (&key force)
   "Get some basic data (custom fields, projects, statuses, etc) from JIRA API.
 
@@ -531,8 +437,7 @@ FORCE will force the request even if the data is already stored."
          (st (lambda () (jira-api-get-statuses :force force :callback fds)))
          (res (lambda () (jira-api-get-resolutions :force force :callback st)))
          (flt (lambda () (jira-api-get-filters :force force :callback res)))
-         (types (lambda () (jira-api-get-issue-types :force force :callback flt)))
-         (prj (lambda () (jira-api-get-projects :force force :callback types)))
+         (prj (lambda () (jira-api-get-projects :force force :callback flt)))
          (account (lambda () (jira-api-get-account-id :force force :callback prj))))
     (funcall account)))
 
