@@ -79,17 +79,7 @@
   t
   "The order to display Jira comments."
   :type '(choice (const :tag "Newest first" t)
-          (const :tag "Oldest first" nil))
-  :group 'jira)
-
-(defcustom jira-detail-reuse-buffer
-  nil
-  "If non-nil, reuse a single Jira detail buffer instead of creating separate
-buffers for each issue.
-When enabled, all issue details will be displayed in one buffer named
- \"*Jira Issue Detail*\" instead of creating separate buffers
-like \"*Jira Issue Detail: [PROJ-123]*\"."
-  :type 'boolean
+                 (const :tag "Oldest first" nil))
   :group 'jira)
 
 ;; they override the default formatters specified
@@ -191,7 +181,7 @@ like \"*Jira Issue Detail: [PROJ-123]*\"."
 
 (cl-defun jira-detail--issue (key issue)
   "Show the detailed information of the ISSUE with KEY."
-  (with-current-buffer (jira-detail--get-issue-buffer key)
+  (with-current-buffer (get-buffer-create (concat "*Jira Issue Detail: [" key "]*"))
     (jira-detail)
     (setq jira-detail--current-key key)
     (setq jira-detail--current issue)
@@ -237,7 +227,6 @@ like \"*Jira Issue Detail: [PROJ-123]*\"."
             (insert "\n\n")))))
     (jira-detail--show-attachments key issue)
     (jira-detail--show-subtasks key issue)
-    (jira-detail--show-linked-issues key issue)
     (jira-detail--show-other key)
     (pop-to-buffer (current-buffer))))
 
@@ -256,9 +245,7 @@ like \"*Jira Issue Detail: [PROJ-123]*\"."
   (let ((key jira-detail--current-key))
     (jira-edit-create-editor-buffer
      (concat "*Jira Description [" key "]*")
-     (let* ((fields (alist-get 'fields jira-detail--current))
-            (description (alist-get 'description fields)))
-       (jira-doc-markup description))
+     ""
      (lambda (new-description)
        (jira-detail--update-field-action
 	"description" (jira-doc-build new-description) key)))))
@@ -268,15 +255,11 @@ like \"*Jira Issue Detail: [PROJ-123]*\"."
   (concat
    (jira-fmt-bold (alist-get 'displayName (alist-get 'author comment)))
    " @ "
-   (jira-fmt-datetime (alist-get 'updated comment))
-   (if (string= (alist-get 'updated comment)
-                (alist-get 'created comment))
-       ""
-     (jira-fmt-bold " (edited)"))))
+   (jira-fmt-datetime (alist-get 'updated comment))))
 
 (defun jira-detail--comments (key comments)
   "Format and insert COMMENTS from issue KEY."
-  (with-current-buffer (jira-detail--get-issue-buffer key)
+  (with-current-buffer (get-buffer-create (concat "*Jira Issue Detail: [" key "]*"))
     (let ((inhibit-read-only t))
       (goto-char (point-max))
       (magit-insert-section (jira-issue-comments nil nil)
@@ -308,7 +291,7 @@ like \"*Jira Issue Detail: [PROJ-123]*\"."
   (let* ((fields (alist-get 'fields issue))
          (subtasks (alist-get 'subtasks fields)))
     (when (and subtasks (sequencep subtasks) (> (length subtasks) 0))
-      (with-current-buffer (jira-detail--get-issue-buffer key)
+      (with-current-buffer (get-buffer-create (concat "*Jira Issue Detail: [" key "]*"))
         (let ((inhibit-read-only t))
           (goto-char (point-max))
           (magit-insert-section (jira-issue-subtasks nil nil)
@@ -316,118 +299,17 @@ like \"*Jira Issue Detail: [PROJ-123]*\"."
               (magit-insert-heading "🔗 Subtasks")
               (magit-insert-section-body
 		(seq-doseq (subtask subtasks)
-                  (let ((subtask-key (alist-get 'key subtask)))
-                    (magit-insert-section (jira-subtask-section subtask-key nil)
-                      (jira-detail--format-issue-entry subtask)))))
+                  (let* ((subtask-key (alist-get 'key subtask))
+			 (subtask-fields (alist-get 'fields subtask))
+			 (subtask-summary (alist-get 'summary subtask-fields))
+			 (subtask-status (alist-get 'status subtask-fields)))
+                    (when (and (stringp subtask-key) (stringp subtask-summary))
+                      (insert (format " - %s  %s %s\n"
+				      (jira-fmt-issue-key-not-tabulated subtask-key)
+				      (jira-fmt-issue-status subtask-status)
+                                      subtask-summary))))))
               (insert "\n"))))))))
 
-(defun jira-detail--get-issue-buffer (key)
-  "Get or create the Jira issue detail buffer for KEY.
-If `jira-detail-reuse-buffer' is enabled, reuse a single buffer for all issues."
-  (if jira-detail-reuse-buffer
-      (get-buffer-create "*Jira Issue Detail*")
-    (get-buffer-create (concat "*Jira Issue Detail: [" key "]*"))))
-
-(defun jira-detail--process-link (link)
-  "Process a single LINK and return (issue direction link-type) tuple."
-  (let* ((link-type (alist-get 'type link))
-         (outward-issue (alist-get 'outwardIssue link))
-         (inward-issue (alist-get 'inwardIssue link)))
-    (cond
-     (outward-issue (list outward-issue "outward" link-type))
-     (inward-issue (list inward-issue "inward" link-type)))))
-
-(defun jira-detail--show-linked-issues (key issue)
-  "Display linked issues for ISSUE with key KEY."
-  (let* ((fields (alist-get 'fields issue))
-         (issuelinks (alist-get 'issuelinks fields)))
-    (when (and issuelinks (sequencep issuelinks) (> (length issuelinks) 0))
-      (with-current-buffer (jira-detail--get-issue-buffer key)
-        (let ((inhibit-read-only t))
-          (goto-char (point-max))
-          (magit-insert-section (jira-issue-linked-issues nil nil)
-            (magit-insert-section (linked-issues-list nil nil)
-              (magit-insert-heading "🔗 Linked Issues")
-              (magit-insert-section-body
-                (seq-doseq (link issuelinks)
-                  (let* ((processed (jira-detail--process-link link))
-                         (issue (car processed))
-                         (direction (cadr processed))
-                         (link-type (caddr processed)))
-                    (when issue
-                      (jira-detail--format-linked-issue issue link-type direction)))))
-              (insert "\n"))))))))
-
-(defun jira-detail--format-issue-entry (issue &optional link-text)
-  "Format a single ISSUE entry, optionally with LINK-TEXT for linked issues.
-This is a shared function used by both subtasks and linked issues."
-  (let* ((issue-key (alist-get 'key issue))
-         (issue-fields (alist-get 'fields issue))
-         (issue-summary (alist-get 'summary issue-fields))
-         (issue-status (alist-get 'status issue-fields)))
-    (if (and (stringp issue-key) (stringp issue-summary))
-        (insert (format " - %s %s %s %s\n"
-                        (if link-text (concat "[" link-text "]") "")
-                        (jira-fmt-issue-key-not-tabulated issue-key)
-                        (jira-fmt-issue-status issue-status)
-                        issue-summary))
-      (insert (format " - [Invalid issue data: %s]\n" issue-key)))))
-
-(defun jira-detail--format-linked-issue (issue link-type direction)
-  "Format a single linked ISSUE with LINK-TYPE and DIRECTION."
-  (let* ((issue-key (alist-get 'key issue))
-         (link-text (if (string= direction "outward")
-                        (alist-get 'outward link-type)
-                      (alist-get 'inward link-type))))
-    (magit-insert-section (jira-linked-issue-section issue-key nil)
-      (jira-detail--format-issue-entry issue (or link-text "[Unknown link type]")))))
-
-(defun jira-detail--open-related-issue-at-point (section-type)
-  "Open the related issue at point in the detail view.
-SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
-  (interactive)
-  (when-let ((issue-key (magit-section-value-if section-type)))
-    (jira-detail-show-issue issue-key)))
-
-(defun jira-detail--open-related-issue-in-browser (section-type)
-  "Open the related issue at point in the browser.
-SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
-  (interactive)
-  (when-let ((issue-key (magit-section-value-if section-type)))
-    (jira-actions-open-issue issue-key)))
-
-(defun jira-detail--related-issue-at-point-p (section-type)
-  "Return non-nil if point is on a SECTION-TYPE section."
-  (magit-section-value-if section-type))
-
-(defvar-keymap jira-subtask-section-map
-  :doc "Keymap for Jira subtask sections."
-  "<RET>" (lambda () (interactive)
-            (jira-detail--open-related-issue-at-point 'jira-subtask-section))
-  "o" (lambda () (interactive)
-        (jira-detail--open-related-issue-in-browser 'jira-subtask-section)))
-
-(defclass jira-subtask-section (magit-section)
-  ((keymap :initform 'jira-subtask-section-map)))
-
-(defvar-keymap jira-linked-issue-section-map
-  :doc "Keymap for Jira linked issue sections."
-  "<RET>" (lambda () (interactive)
-            (jira-detail--open-related-issue-at-point 'jira-linked-issue-section))
-  "o" (lambda () (interactive)
-        (jira-detail--open-related-issue-in-browser 'jira-linked-issue-section)))
-
-(defclass jira-linked-issue-section (magit-section)
-  ((keymap :initform 'jira-linked-issue-section-map)))
-
-(defun jira-detail--subtask-at-point-p ()
-  "Return non-nil if point is on a subtask section."
-  (jira-detail--related-issue-at-point-p 'jira-subtask-section))
-
-(defun jira-detail--linked-issue-at-point-p ()
-  "Return non-nil if point is on a linked issue section."
-(jira-detail--related-issue-at-point-p 'jira-linked-issue-section))
-
 (defvar-keymap jira-attachment-section-map
   :doc "Keymap for Jira attachment sections."
   "<RET>" #'jira-detail--get-attachment)
@@ -440,14 +322,14 @@ SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
   (let* ((fields (alist-get 'fields issue))
          (attachments (alist-get 'attachment fields)))
     (when (> (length attachments) 0)
-      (with-current-buffer (jira-detail--get-issue-buffer key)
+      (with-current-buffer (get-buffer-create (concat "*Jira Issue Detail: [" key "]*"))
 	(let ((inhibit-read-only t))
           (goto-char (point-max))
           (magit-insert-section (jira-issue-attachments nil nil)
 	    (magit-insert-section (attachements-list nil nil)
               (magit-insert-heading "📎 Attachments (press RET to visualize)")
               (magit-insert-section-body
-		(mapc
+		(mapcar
 		 (lambda (attachment)
 		   (let* ((url (url-generic-parse-url (alist-get 'content attachment)))
                           ;; FIXME: verify that filename matches
@@ -483,7 +365,6 @@ SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
     (_ (error "Not a Jira attachment"))))
 
 (defun jira-detail--show-attachment (name data)
-  "Show attachment NAME with DATA in a new buffer."
   (let ((x (generate-new-buffer-name name)))
     (pop-to-buffer x)
     (insert data)
@@ -491,18 +372,17 @@ SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
     ;; Bind these so `normal-mode' will check the buffer contents
     ;; instead of just looking for a -*- line.
     (let ((buffer-file-name (file-name-concat temporary-file-directory
-                                              name))
+                                             name))
           (default-directory temporary-file-directory))
       (normal-mode))
     (set-buffer-modified-p t)))
 
 (defun jira-detail--show-other (key)
-  "Show other issue details for KEY."
   (jira-detail--watchers
    key
    (lambda (data _response)
      (jira-detail--show-comments key)
-     (with-current-buffer (jira-detail--get-issue-buffer key)
+     (with-current-buffer (get-buffer-create (concat "*Jira Issue Detail: [" key "]*"))
        (let ((inhibit-read-only t)
              (names (mapcar (lambda (u)
                               (alist-get 'displayName u))
@@ -519,8 +399,7 @@ SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
                        "\n\n")))))))))
 
 (defun jira-detail--watchers (key callback)
-  "Show the watchers list of issue with KEY.
-CALLBACK is called with the watchers data."
+  "Show the watchers list of issue with KEY."
   (jira-api-call "GET"
                  (format "issue/%s/watchers" key)
                  :callback callback))
@@ -532,7 +411,6 @@ CALLBACK is called with the watchers data."
    :callback (lambda (data _) (jira-detail--issue key data))))
 
 (defun jira-detail--remove-comment-at-point ()
-  "Remove the comment at point."
   (let ((current-section (magit-current-section)))
     (if current-section
 	(if (string-equal (caar (magit-section-ident current-section)) "comment")
@@ -541,37 +419,13 @@ CALLBACK is called with the watchers data."
                 (jira-actions-delete-comment
 		 jira-detail--current-key
                  comment-id
-		 (lambda () (jira-detail-show-issue jira-detail--current-key)))))
+		 (lambda () (jira-detail-show-issue jira-detail--current-key))))
+	      )
 	  (message "No comment at point"))
       (message "No comment at point"))))
 
-(defun jira-detail--edit-comment-at-point ()
-  "Edit the comment at point."
-  (magit-section-case
-    (comment
-     (let ((comment-id (magit-section-ident-value (magit-current-section)))
-           (issue-key jira-detail--current-key))
-       (jira-edit-create-editor-buffer
-        (format "*Jira Comment Update %s: %s*" comment-id issue-key)
-        (let* ((fields (alist-get 'fields jira-detail--current))
-               (comment (alist-get 'comment fields))
-               (comments (alist-get 'comments comment))
-               (comment (seq-find (lambda (c)
-                                    (string= (alist-get 'id c)
-                                             comment-id))
-                                  comments)))
-          (if comment
-              (jira-doc-markup (alist-get 'body comment))
-            (error "Comment %s not found in %s" comment-id issue-key)))
-        (lambda (content)
-          (jira-actions-edit-comment issue-key
-                                     comment-id
-                                     content
-                                     (lambda ()
-                                       (jira-detail-show-issue issue-key)))))))))
-
 (defun jira-detail--update-field-action (field-id value key)
-  "Update FIELD-ID with VALUE for the current issue KEY."
+  ;; Update FIELD-ID with VALUE for the current issue.
   (jira-api-call
    "PUT" (concat "issue/" key)
    :data `(("fields" . ((,field-id . ,value))))
@@ -585,14 +439,14 @@ CALLBACK is called with the watchers data."
    :callback (lambda (data _response) (jira-detail-show-issue (alist-get 'key data)))))
 
 (defun jira-detail--update-timetracking-action (field-id value key)
-  "Update timetracking FIELD-ID with VALUE for the current issue KEY."
+  ;; Update timetracking FIELD-ID with VALUE for the current issue.
   (jira-api-call
    "PUT" (concat "issue/" key)
    :data `(("fields" . (("timetracking" . ((,field-id . ,value))))))
    :callback (lambda (_data _response) (jira-detail-show-issue key))))
 
 (defun jira-detail--ensure-update-metadata ()
-  "Ensure jira-detail--current-update-metadata is populated and return it."
+  ;; Ensure jira-detail--current-update-metadata is populated and return it.
   (unless jira-detail--current-update-metadata
     (let* ((issue-type-id (jira-table-extract-field
 			   jira-issues-fields
@@ -609,7 +463,6 @@ CALLBACK is called with the watchers data."
   jira-detail--current-update-metadata)
 
 (defun jira-detail--updatable-field-id (field-name)
-  "Get the updatable field ID for FIELD-NAME."
   (let ((id (cdr (assoc field-name jira-detail--updatable-fields))))
     (if (and (consp id) (eq (car id) :custom))
         (cdr (assoc (cdr id) jira-fields))
@@ -666,15 +519,14 @@ CALLBACK is called with the watchers data."
    ("+" "Add comment to issue"
     (lambda () (interactive ) (jira-detail--add-comment jira-detail--current-key)))
    ("-" "Remove comment at point"
-    (lambda () (interactive ) (jira-detail--remove-comment-at-point)))
-   ("e" "Edit comment at point"
-    (lambda () (interactive) (jira-detail--edit-comment-at-point)))]
+    (lambda () (interactive ) (jira-detail--remove-comment-at-point)))]
   ["Issue Actions"
    ("C" "Change issue status"
-    (lambda () (interactive) (call-interactively #'jira-actions-change-issue-menu)))
+    (lambda () (interactive) (jira-actions-change-issue-menu)))
    ("O" "Open issue in browser"
     (lambda () (interactive) (jira-actions-open-issue jira-detail--current-key)))
    ("P" "Show parent issue" (lambda () (interactive) (jira-detail--show-parent-issue)))
+   ("S" "Add subtask" (lambda () (interactive) (jira-detail--create-subtask)))
    ("U" "Update issue field"
     (lambda () (interactive) (jira-detail--update-field)))
    ("w" "Update watchers" jira-detail--watchers-menu)
@@ -684,25 +536,7 @@ CALLBACK is called with the watchers data."
     (lambda () (interactive)
       (jira-actions-copy-issues-id-to-clipboard jira-detail--current-key)))
    ("g" "Refresh issue detail"
-    (lambda () (interactive) (jira-detail-show-issue jira-detail--current-key)))
-   ("S" "Add subtask"
-    (lambda () (interactive) (jira-detail--create-subtask)))]
-  [:if jira-detail--subtask-at-point-p
-   "Subtask at point"
-   ("RET" "Open subtask"
-    (lambda () (interactive)
-      (jira-detail--open-related-issue-at-point 'jira-subtask-section)))
-   ("o" "Open subtask in browser"
-    (lambda () (interactive)
-      (jira-detail--open-related-issue-in-browser 'jira-subtask-section)))]
-  [:if jira-detail--linked-issue-at-point-p
-   "Linked issue at point"
-   ("RET" "Open linked issue"
-    (lambda () (interactive)
-        (jira-detail--open-related-issue-at-point 'jira-linked-issue-section)))
-   ("o" "Open linked issue in browser"
-    (lambda () (interactive)
-      (jira-detail--open-related-issue-in-browser 'jira-linked-issue-section)))])
+    (lambda () (interactive) (jira-detail-show-issue jira-detail--current-key)))])
 
 (defvar jira-detail-changed-hook nil
   "Hook run after a Jira issue has been changed in jira-detail-mode.")
@@ -712,15 +546,12 @@ CALLBACK is called with the watchers data."
     (define-key map (kbd "?") 'jira-detail--actions-menu)
     (define-key map (kbd "+")
 		(lambda () (interactive ) (jira-detail--add-comment jira-detail--current-key)))
-    (define-key map (kbd "e")
-                (lambda () "Edit comment at point"
-                  (interactive) (jira-detail--edit-comment-at-point)))
     (define-key map (kbd  "-")
 		(lambda () "Remove comment at point"
 		  (interactive) (jira-detail--remove-comment-at-point)))
     (define-key map (kbd "C")
 		(lambda () "Change issue status"
-		  (interactive) (call-interactively #'jira-actions-change-issue-menu)))
+		  (interactive) (jira-actions-change-issue-menu)))
     (define-key map (kbd "O")
 		(lambda () "Open issue in browser"
 		  (interactive)  (jira-actions-open-issue jira-detail--current-key)))
@@ -738,7 +569,6 @@ CALLBACK is called with the watchers data."
     (define-key map (kbd "g")
 		(lambda () "Refresh issue detail"
 		  (interactive) (jira-detail-show-issue jira-detail--current-key)))
-    (define-key map (kbd "h") 'jira-detail--actions-menu)
     (define-key map (kbd "P")
 		(lambda () "Show parent issue"
 		  (interactive) (jira-detail--show-parent-issue)))
@@ -748,8 +578,7 @@ CALLBACK is called with the watchers data."
   "Keymap for Jira Issue Detail buffers.")
 
 (defun jira-detail--show-parent-issue ()
-  "Show the detail view of the parent issue.
-Shows the detail view of the parent issue for the current issue."
+  "Show the detail view of the parent issue."
   (interactive)
   (let ((parent-key (jira-detail--issue-fmt jira-detail--current :parent-key)))
     (if (and parent-key (not (string= parent-key "")))
