@@ -38,29 +38,19 @@
 (require 'jira-tempo)
 (require 'jira-actions)
 (require 'jira-detail)
-(require 'jira-export)
 
 (defcustom jira-issues-table-fields
   '(:key :issue-type-name :status-name :assignee-name
-	 :progress-percent :work-ratio :remaining-time :summary)
+    :progress-percent :work-ratio :remaining-time :summary)
   "Fields to show in the Jira issues table.
 
-Allowed values in variable `jira-issues-fields'."
-  :group 'jira :type '(repeat (symbol :tag "Field")))
+Allowed values in variable jira-issues-fields."
+  :group 'jira :type 'list)
 
 (defcustom jira-issues-max-results 30
   "Maximum number of Jira issues to retrieve."
   :group 'jira :type 'integer)
 
-(defcustom jira-issues-default-type nil
-  "Default issue type filter for the issues list.
-When set to a type name (e.g., \"Epic\", \"Story\", \"Bug\"), the issues
-list will automatically filter to show only that type unless explicitly
-overridden via the transient menu."
-  :group 'jira
-  :type '(choice (const :tag "No default filter" nil)
-                 (string :tag "Issue type name")))
-
 (defvar jira-issues--loading-p nil
   "A flag to indicate if an API call is in progress.")
 (defvar jira-issues--current-jql nil
@@ -71,8 +61,6 @@ overridden via the transient menu."
   "The pagination token for the next page of issues.")
 (defvar jira-issues--pagination-previous nil
   "A list of pagination tokens for previously viewed pages.")
-(defvar jira-issues--raw-issues nil
-  "The raw issues data for the current page.")
 
 
 ;; files that we always want to retrieve because they are used
@@ -83,19 +71,8 @@ overridden via the transient menu."
   "Hash map to store issue keys and the associated summaries.
 This information is added to worklogs to make it easier to identify")
 
-(defcustom jira-issues-sort-key (cons "Status" nil)
-  "Default tabulated-list sort key for jira-issues-mode.
-Value is a cons (COLUMN . DESCENDING). When DESCENDING is non-nil, sort
-order is descending. COLUMN must match one of the visible tabulated-list
-column headers."
-  :group 'jira
-  :type '(cons (string :tag "Column")
-          (boolean :tag "Descending")))
-
 (defun jira-issues--api-get-issues (jql callback &optional page-token)
-  "Retrieve issues from the given JQL filter and call CALLBACK function.
-
-PAGE-TOKEN is optional and used for pagination."
+  "Retrieve issues from the given JQL filter and call CALLBACK function."
   (let* ((parent (lambda (fd) (jira-table-field-parent jira-issues-fields fd)))
          (fields (append (mapcar parent jira-issues-table-fields)
 			 jira-issues-required-fields))
@@ -110,9 +87,7 @@ PAGE-TOKEN is optional and used for pagination."
 
 (defun jira-issues--api-filters-and (filters)
   "Concat all FILTERS with AND."
-  (let ((valid-filters (remove nil filters)))
-    (when valid-filters
-      (mapconcat (lambda (filter) filter) valid-filters " AND "))))
+  (mapconcat (lambda (filter) filter) (remove nil filters) " AND "))
 
 (defun jira-issues--data-format-cell (issue field)
   "Format the given FIELD from the given ISSUE."
@@ -149,7 +124,6 @@ PAGE-TOKEN is optional and used for pagination."
   (message "Jira API request failed"))
 
 (defun jira-issues--fetch-and-display (page-token)
-  "Fetch and display issues for the given PAGE-TOKEN."
   (when (not jira-issues--loading-p)
     (setq jira-issues--loading-p t)
     (setq jira-issues--pagination-current page-token)
@@ -180,92 +154,74 @@ PAGE-TOKEN is optional and used for pagination."
     (setq jira-issues--pagination-next next-token)
     (when jira-debug
       (message "Jira Issues: Page %d" (1+ (length jira-issues--pagination-previous))))
-    (setq jira-issues--raw-issues issues)
     (setq tabulated-list-entries (mapcar #'jira-issues--data-format-issue issues))
     (setq jira-issues-key-summary-map (jira-issues-store-issues-info issues))
     (tabulated-list-print t)
     (setq jira-issues--loading-p nil)))
 
-(defun jira-issues--reset-pagination ()
-  "Reset pagination state to start from the beginning."
-  (setq jira-issues--pagination-current nil)
-  (setq jira-issues--pagination-next nil)
-  (setq jira-issues--pagination-previous nil)
-  (setq jira-issues--raw-issues nil))
-
 (defun jira-issues--refresh ()
   "Refresh the table."
   (let* ((args (transient-args 'jira-issues-menu))
          (myself (transient-arg-value "--myself" args))
          (current-sprint (transient-arg-value "--current-sprint" args))
-         (jql (transient-arg-value "--jql=" args))
+	 (filter-name (transient-arg-value "--filter=" args))
+         (jql (or (transient-arg-value "--jql=" args)
+		  (when filter-name (cdr (assoc filter-name jira-filters)))))
          (status (transient-arg-value "--status=" args))
          (project (transient-arg-value "--project=" args))
          (resolution (transient-arg-value "--resolution=" args))
          (version (transient-arg-value "--version=" args))
          (assignee (transient-arg-value "--assignee=" args))
-         (reporter (transient-arg-value "--reporter=" args))
-         (issue-type (transient-arg-value "--type=" args))
-         ;; Use explicit type if set, otherwise fall back to default
-         ;; If type is "" (Any), then it's effectively nil (no filter)
-         (effective-type (cond
-                          ((string= issue-type "") nil)
-                          (issue-type issue-type)
-                          (t jira-issues-default-type))))
-    (let ((additional-filters
-           (list (when myself "assignee = currentUser()")
-                 (when current-sprint "sprint in openSprints()")
-                 (when status (concat "status = \"" status "\""))
-                 (when project (concat "project = \"" project "\""))
-                 (when resolution (concat "resolution = \"" resolution "\""))
-                 (when version (concat "fixversion = \"" version "\""))
-                 (when effective-type (concat "issuetype = \"" effective-type "\""))
-                 (when assignee
-                   (if (string-match-p "EMPTY" assignee)
-                       "assignee = EMPTY"
-                     (let ((account-id (gethash assignee jira-users)))
-                       (when account-id (concat "assignee = " account-id)))))
-                 (when reporter
-                   (let ((account-id (gethash reporter jira-users)))
-                     (when account-id (concat "reporter = " account-id)))))))
-      (setq jira-issues--current-jql
-            (if jql
-                ;; If we have base JQL, combine it with additional filters
-                (let ((additional-jql (jira-issues--api-filters-and additional-filters)))
-                  (if (and additional-jql (not (string= additional-jql "")))
-                      (concat "(" jql ") AND " additional-jql)
-                    jql))
-              ;; No base JQL, just use additional filters
-              (jira-issues--api-filters-and additional-filters)))))
-  (jira-issues--reset-pagination)
-  (jira-issues--fetch-and-display nil))
+         (reporter (transient-arg-value "--reporter=" args)))
+    (setq jira-issues--current-jql
+          (or jql
+              (jira-issues--api-filters-and
+               (list (when myself "assignee = currentUser()")
+                     (when current-sprint "sprint in openSprints()")
+                     (when status (concat "status = \"" status "\""))
+                     (when project (concat "project = \"" project "\""))
+                     (when resolution (concat "resolution = \"" resolution "\""))
+                     (when version (concat "fixversion = \"" version "\""))
+                     (when assignee
+                       (if (string-match-p "EMPTY" assignee)
+                           "assignee = EMPTY"
+                         (let ((account-id (gethash assignee jira-users)))
+                           (when account-id (concat "assignee = " account-id)))))
+                     (when reporter
+                       (let ((account-id (gethash reporter jira-users)))
+                         (when account-id (concat "reporter = " account-id))))))))
+    (setq jira-issues--pagination-current nil)
+    (setq jira-issues--pagination-next nil)
+    (setq jira-issues--pagination-previous nil)
+    (jira-issues--fetch-and-display nil)))
 
+(defun jira-issues--filter-invalid-if-jql ()
+  "Return t if JQL filter is set."
+  (if transient-current-command
+      (or (transient-arg-value "--jql=" (transient-args transient-current-command))
+	  (transient-arg-value "--filter=" (transient-args transient-current-command)))))
 
 (defun jira-issues--myself-inapt-p ()
-  "Return t if assignee is set."
+  "Return t if JQL, filter or assignee is set."
   (if transient-current-command
       (let ((args (transient-args transient-current-command)))
-	(transient-arg-value "--assignee=" args))))
+	(or (transient-arg-value "--jql=" args)
+	    (transient-arg-value "--filter=" args)
+	    (transient-arg-value "--assignee=" args)))))
 
 (defun jira-issues--assignee-inapt-p ()
-  "Return t if myself is set."
+  "Return t if JQL, filter or myself is set."
   (if transient-current-command
       (let ((args (transient-args transient-current-command)))
-	(transient-arg-value "--myself" args))))
+	(or (transient-arg-value "--jql=" args)
+            (transient-arg-value "--filter=" args)
+            (transient-arg-value "--myself" args)))))
 
 
-
-(defun jira-issues--transient-default-value ()
-  "Return default transient value including default issue type if set."
-  (let ((defaults '("--myself")))
-    (when jira-issues-default-type
-      (push (concat "--type=" jira-issues-default-type) defaults))
-    defaults))
-
 (transient-define-prefix jira-issues-menu ()
   "Show menu for listing Jira Issues."
   :refresh-suffixes t
-  :value #'jira-issues--transient-default-value
+  :value '("--myself")
   [["Arguments"
     ("a" "Assignee" "--assignee="
      :transient transient--do-call
@@ -276,33 +232,39 @@ PAGE-TOKEN is optional and used for pagination."
      :transient transient--do-call
      :inapt-if jira-issues--myself-inapt-p)
     ("c" "Just from current sprint" "--current-sprint"
-     :transient t)
+     :transient t
+     :inapt-if jira-issues--filter-invalid-if-jql)
     ("s" "Status" "--status="
      :transient t
+     :inapt-if jira-issues--filter-invalid-if-jql
      :choices
      (lambda () (mapcar (lambda (st) (car st)) jira-statuses)))
     ("p" "Project" "--project="
      :transient t
+     :inapt-if jira-issues--filter-invalid-if-jql
      :choices
      (lambda () (mapcar (lambda (prj) (car prj)) jira-projects)))
     ("R" "Reporter" "--reporter="
      :transient t
+     :inapt-if jira-issues--filter-invalid-if-jql
      :choices
      (lambda () (when jira-users (hash-table-keys jira-users))))
     ("r" "Resolution" "--resolution="
      :transient t
+     :inapt-if jira-issues--filter-invalid-if-jql
      :choices
      (lambda () (mapcar (lambda (res) (car res)) jira-resolutions)))
+    ("f" "Filter" "--filter="
+     :transient transient--do-call
+     :choices
+     (lambda () (if jira-filters (mapcar 'car jira-filters) (message "No filters found"))))
     ("j""JQL filter" "--jql="
      :transient transient--do-call)
     ("v" "Fix Versions" "--version="
      :transient t
+     :inapt-if jira-issues--filter-invalid-if-jql
      :choices
-     (lambda () (apply #'append (mapcar #'cdr jira-projects-versions))))
-    ("t" "Issue Type" "--type="
-     :transient t
-     :choices
-     (lambda () (cons '("Any" "") (mapcar #'car jira-issue-types))))]
+     (lambda () (apply #'append (mapcar #'cdr jira-projects-versions))))]
    ["Arguments Help"
     ("C-x" :info (concat (jira-fmt-set-face "Check " 'italic)
                          "additional options"))
@@ -314,33 +276,13 @@ PAGE-TOKEN is optional and used for pagination."
                              " arguments to default ones"))]]
 
   ["Actions"
-   ("l" "List Jira Issues" tablist-revert)
-   ("F" "Apply named filter" (lambda (&optional _) (interactive) (jira-issues--apply-filter)))])
+   ("l" "List Jira Issues" tablist-revert)])
 
 (defun jira-issues--jump-to-tempo ()
   "Jump to Tempo worklogs, closing current buffer."
   (kill-buffer (buffer-name))
   (jira-tempo))
 
-(defun jira-issues--switch-host-and-refresh ()
-  "Switch JIRA host and refresh the issue list."
-  (interactive)
-  (let ((selected-host (completing-read "JIRA host: " (jira-api--available-urls))))
-    (jira-api--set-current-url selected-host)
-    (jira-api-get-basic-data)
-    (tablist-revert)))
-
-(defun jira-issues--apply-filter ()
-  "Apply a named filter and warn user that other arguments won't be applied."
-  (if (not jira-filters)
-      (message "No filters found")
-    (let ((selected-filter (completing-read "Filter: " (mapcar #'car jira-filters))))
-      (when selected-filter
-        (message "Filter applied: %s (other arguments will be ignored)" selected-filter)
-        (setq jira-issues--current-jql (cdr (assoc selected-filter jira-filters)))
-        (jira-issues--reset-pagination)
-        (jira-issues--fetch-and-display nil)))))
-
 (transient-define-prefix jira-issues-actions-menu ()
   "Show menu for actions on Jira Issues."
   [[:description "Jira Issues List"
@@ -351,8 +293,6 @@ PAGE-TOKEN is optional and used for pagination."
 		  (lambda () (interactive) (jira-detail-find-issue-by-key)))
 		 ("T" "Jump to Tempo worklogs"
 		  (lambda () (interactive) (jira-issues--jump-to-tempo)))
-		 ("H" "Switch JIRA host" jira-issues--switch-host-and-refresh)
-		 ("e" "Export issues" jira-export-menu)
                  ("M-n" "Next page" jira-issues-next-page)
                  ("M-p" "Previous page" jira-issues-previous-page)]]
   [[:description
@@ -377,8 +317,6 @@ PAGE-TOKEN is optional and used for pagination."
   (let ((map (make-sparse-keymap)))
     (define-key map "?" 'jira-issues-actions-menu)
     (define-key map "l" 'jira-issues-menu)
-    (define-key map "h" 'jira-issues-actions-menu)
-    (define-key map "H" 'jira-issues--switch-host-and-refresh)
     (define-key map "T" (lambda () (interactive) (jira-issues--jump-to-tempo)))
     (define-key map "f" (lambda () (interactive) (jira-detail-find-issue-by-key)))
     (define-key map (kbd "c")
@@ -387,12 +325,9 @@ PAGE-TOKEN is optional and used for pagination."
     (define-key map "C" 'jira-actions-change-issue-menu)
     (define-key map "I" (lambda () (interactive)
                           (jira-detail-show-issue (jira-utils-marked-item))))
-    (define-key map (kbd "RET") (lambda () (interactive)
-                                  (jira-detail-show-issue (jira-utils-marked-item))))
     (define-key map "O" (lambda () (interactive)
                           (jira-actions-open-issue (jira-utils-marked-item))))
     (define-key map "W" 'jira-actions-add-worklog-menu)
-    (define-key map "e" 'jira-export-menu)
     (define-key map (kbd "M-n") 'jira-issues-next-page)
     (define-key map (kbd "M-p") 'jira-issues-previous-page)
     map)
@@ -404,7 +339,6 @@ PAGE-TOKEN is optional and used for pagination."
   (interactive)
   (switch-to-buffer "*Jira Issues*")
   (jira-issues-mode)
-  (jira-api--initialize-current-url)
   (jira-api-get-basic-data)
   (tablist-revert))
 
@@ -417,7 +351,7 @@ PAGE-TOKEN is optional and used for pagination."
     (setq tabulated-list-format
           (vconcat (mapcar col-info jira-issues-table-fields))))
 
-  (setq tabulated-list-sort-key jira-issues-sort-key)
+  (setq tabulated-list-sort-key (cons "Status" nil))
   (setq tabulated-list-padding 2)
   (add-hook 'tabulated-list-revert-hook #'jira-issues--refresh nil t)
   (add-hook 'jira-issues-changed-hook #'tablist-revert)
